@@ -5,14 +5,14 @@ penalized <- function(response, penalized, unpenalized, lambda1=0, lambda2=0, da
   startbeta, startgamma, steps =1, epsilon = 1e-10, maxiter, standardize = FALSE, trace = TRUE) {
 
   # determine the response
-  if (!missing(data)) response <- eval(as.list(match.call())$response, data)
+  if (!missing(data)) response <- eval(as.list(match.call())$response, data, globalenv())
   if (is(response, "formula")) {
     if (!missing(penalized)) warning("Ignoring \"penalized\" argument because \"response\" is a formula.", call.=FALSE)
     penalized <- response
     if (missing(data)) 
-      response <- eval(attr(terms(response), "variables"))[[attr(terms(response), "response")]]
+      response <- eval(attr(terms(response), "variables"), globalenv())[[attr(terms(response), "response")]]
     else
-      response <- eval(attr(terms(response), "variables"), data)[[attr(terms(response), "response")]]
+      response <- eval(attr(terms(response), "variables"), data, globalenv())[[attr(terms(response), "response")]]
   }
 
   
@@ -157,14 +157,14 @@ cvl <- function(response, penalized, unpenalized, lambda1 = 0, lambda2= 0, data,
   epsilon = 1e-10, maxiter, standardize = FALSE, trace = TRUE) {
 
   # determine the response
-  if (!missing(data)) response <- eval(as.list(match.call())$response, data)
+  if (!missing(data)) response <- eval(as.list(match.call())$response, data, globalenv())
   if (is(response, "formula")) {
     if (!missing(penalized)) warning("Ignoring \"penalized\" argument because \"response\" is a formula.", call.=FALSE)
     penalized <- response
     if (missing(data)) 
-      response <- eval(attr(terms(response), "variables"))[[attr(terms(response), "response")]]
+      response <- eval(attr(terms(response), "variables"), globalenv())[[attr(terms(response), "response")]]
     else
-      response <- eval(attr(terms(response), "variables"), data)[[attr(terms(response), "response")]]
+      response <- eval(attr(terms(response), "variables"), data, globalenv())[[attr(terms(response), "response")]]
   }
 
   # determine the model if missing
